Dimens class

Constructors

Dimens()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dialogRadius double
getter/setter pair
doubleRadius double
getter/setter pair
doubleSpacing double
getter/setter pair
halfSpacing double
getter/setter pair
minimalButtonSize double
getter/setter pair
quadrupleSpacing double
getter/setter pair
standardRadius double
getter/setter pair
standardSpacing double
getter/setter pair
tripleSpacing double
getter/setter pair