StaticRowTableElement class

Constructors

StaticRowTableElement({required Widget rowBuilder(), bool displayBuilder()?})

Properties

displayBuilder bool Function()?
final
hashCode int
The hash code for this object.
no setterinherited
rowBuilder Widget Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited